@@ -120,3 +120,13 @@ class Customer(Creatable, Queryable, Retrievable, Updatable, Deletable):
         """
         cleaned_data = data.dict(exclude_unset=True, exclude_none=True)
         return cast('Customer', cls._update(id=id, **cleaned_data))
+
+    @classmethod
+    def tax_info_validation(cls, id: str):
+        """Tax info validation.
+
+        Args:
+            id: ID of the customer to be validated.
+        """
+        return cls._tax_info_validation(id=id)
+        #return cast('Organizations', )
