@@ -110,6 +110,22 @@ class Organizations(Creatable, Queryable, Retrievable, Updatable, Deletable):
         keys = Organizations.retrieve_keys(id=id,env=env)
         print(keys)
         return keys
+    
+    @classmethod
+    def get_live_key(cls, id: str, env: str):
+        """Update an Organization.
+
+        Args:
+            id: ID of the Organization to be updated.
+            data: Data to be updated.
+
+        Returns:
+            Organization: The udpated Organization resource.
+        """
+
+        keys = Organizations.retrieve_live_keys(id=id,env=env)
+        print(keys)
+        return keys
 
     @classmethod
     def upload_certs(cls, id: str, data, files):
